[prev in list] [next in list] [prev in thread] [next in thread] 

List:       lyx-devel
Subject:    [patch] fix for bug 8613
From:       Uwe Stöhr <uwestoehr () web ! de>
Date:       2013-03-29 1:34:26
Message-ID: 5154EFA2.2080904 () web ! de
[Download RAW message or body]

Bugreport 8613 unveils that the package varioref must be loaded after the package babel to assure 
that the correct language is used for formatted cross-references.

The attached patch fixes this. OK to commit or does anybody sees possible conflicts when varioref is 
load as one of the last packages?

regards Uwe

["bug8613.diff" (text/x-patch)]

 src/BufferParams.cpp | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/src/BufferParams.cpp b/src/BufferParams.cpp
index 57ab957..da18832 100644
--- a/src/BufferParams.cpp
+++ b/src/BufferParams.cpp
@@ -1763,10 +1763,12 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 	// http://www.mail-archive.com/lyx-devel@lists.lyx.org/msg144349.html
 	lyxpreamble += from_ascii(features.getColorOptions());
 
 	// If we use hyperref, jurabib, japanese, or vietnamese, we have to call babel before them.
 	if (use_babel
 	    && (features.isRequired("jurabib")
 		|| features.isRequired("hyperref")
+		|| features.isRequired("varioref")
 		|| features.isRequired("vietnamese")
 		|| features.isRequired("japanese"))) {
 			// FIXME UNICODE
@@ -1925,9 +1927,10 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 			+ atlyxpreamble + "\\makeatother\n\n";
 
 	// We try to load babel late, in case it interferes with other packages.
 	// Jurabib and Hyperref have to be called after babel, though.
 	if (use_babel && !features.isRequired("jurabib")
 	    && !features.isRequired("hyperref")
+	    && !features.isRequired("varioref")
 	    && !features.isRequired("vietnamese")
 	    && !features.isRequired("japanese")) {
 		// FIXME UNICODE
@@ -1763,10 +1763,12 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 	lyxpreamble += from_ascii(features.getColorOptions());
 
-	// If we use hyperref, jurabib, japanese, or vietnamese, we have to call babel before them.
+	// If we use hyperref, jurabib, japanese, varioref or vietnamese,
+	// we have to call babel before
 	if (use_babel
 	    && (features.isRequired("jurabib")
@@ -1925,9 +1927,10 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 
 	// We try to load babel late, in case it interferes with other packages.
-	// Jurabib and Hyperref have to be called after babel, though.
+	// Jurabib, hyperref and varioref have to be called after babel, though.
 	if (use_babel && !features.isRequired("jurabib")
 	    && !features.isRequired("hyperref")


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic